==> mastapy-14.0.0.tar.gz: mastapy-14.0.0/mastapy/_private/utility/units_and_measurements/measurements/_1683.py <==
"""ElectricalResistance"""

from __future__ import annotations

from typing import ClassVar, TYPE_CHECKING

from mastapy._private._internal import utility
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.python_net import python_net_import
from mastapy._private.utility.units_and_measurements import _1655

_ELECTRICAL_RESISTANCE = python_net_import(
    "SMT.MastaAPI.Utility.UnitsAndMeasurements.Measurements", "ElectricalResistance"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="ElectricalResistance")
    CastSelf = TypeVar(
        "CastSelf", bound="ElectricalResistance._Cast_ElectricalResistance"
    )


__docformat__ = "restructuredtext en"
__all__ = ("ElectricalResistance",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_ElectricalResistance:
    """Special nested class for casting ElectricalResistance to subclasses."""

    __parent__: "ElectricalResistance"

    @property
    def measurement_base(self: "CastSelf") -> "_1655.MeasurementBase":
        return self.__parent__._cast(_1655.MeasurementBase)

    @property
    def electrical_resistance(self: "CastSelf") -> "ElectricalResistance":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class ElectricalResistance(_1655.MeasurementBase):
    """ElectricalResistance

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _ELECTRICAL_RESISTANCE

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def cast_to(self: "Self") -> "_Cast_ElectricalResistance":
        """Cast to another type.

        Returns:
            _Cast_ElectricalResistance
        """
        return _Cast_ElectricalResistance(self)

==> mastapy-14.1.0b2.tar.gz: mastapy-14.1.0b2/mastapy/_private/utility/units_and_measurements/measurements/_1683.py <==
"""Area"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal import utility
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.python_net import python_net_import
from mastapy._private.utility.units_and_measurements import _1666

_AREA = python_net_import(
    "SMT.MastaAPI.Utility.UnitsAndMeasurements.Measurements", "Area"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="Area")
    CastSelf = TypeVar("CastSelf", bound="Area._Cast_Area")


__docformat__ = "restructuredtext en"
__all__ = ("Area",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_Area:
    """Special nested class for casting Area to subclasses."""

    __parent__: "Area"

    @property
    def measurement_base(self: "CastSelf") -> "_1666.MeasurementBase":
        return self.__parent__._cast(_1666.MeasurementBase)

    @property
    def area(self: "CastSelf") -> "Area":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class Area(_1666.MeasurementBase):
    """Area

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _AREA

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def cast_to(self: "Self") -> "_Cast_Area":
        """Cast to another type.

        Returns:
            _Cast_Area
        """
        return _Cast_Area(self)
